==> arknights_mower-1.3.0-py3-none-any.whl: arknights_mower/data/ocr.py <==
ocr_error = {
    '削男': '削弱',
    'HU男易': '削弱',
    '背身易': '削弱',
    '尚身易': '削弱',
    '尚小深深': '削弱',
    '技巧概要卷1': '技巧概要·卷1',
    '技巧概要卷2': '技巧概要·卷2',
    '医疗千员': '医疗干员',
    '先锋千员': '先锋干员',
    '近卫千员': '近卫干员',
    '术师千员': '术师干员',
    '辅助千员': '辅助干员',
    '高级资深千员': '高级资深干员',
    '狙击千员': '狙击干员',
    '重装千员': '重装干员',
    '特种千员': '特种干员',
    '资深千员': '资深干员',
    '聚酸醋': '聚酸酯',
    '醋原料': '酯原料',
    '龙门市': '龙门币',
    '酮爆集': '酮凝集',
    '租击干员': '狙击干员',
    '草': '苇草',
    '蒂草': '苇草',
    '叫米': '古米',
    '劳': '芬',
    '舔': '砾',
    '乐': '砾',
    'THRMEX': 'THRM-EX',
    '身': '宴',
    '白面': '白面鸮',
    '白面鹑': '白面鸮',
    '白面鹗': '白面鸮',
    '白面鸭': '白面鸮',
    '白面男': '白面鸮',
    '使影': '傀影',
    '倪影': '傀影',
    '巡林': '巡林者',
    '可巡林者': '巡林者',
    'Castle3': 'Castle-3',
    'CastIe3': 'Castle-3',
    'Lancet2': 'Lancet-2',
    '碗星': '陨星',
    '限星': '陨星',
    '星': '陨星',
    '叶': '吽',
    '耳': '吽',
    '哗': '吽',
    '灰': '灰烬',
    '桑衰': '桑葚',
    '桑甚': '桑葚',
    '罗比塔': '罗比菈塔',
    '罗比藏塔': '罗比菈塔',
    '罗比拉塔': '罗比菈塔',
    '罗比益塔': '罗比菈塔',
    '蛇居箱': '蛇屠箱',
    '荣草': '苇草',
    '石': '燧石',
    '狮蜴': '狮蝎',
    '琴迎': '琴柳',
    '看草': '香草',
    '番草': '香草',
    '惊': '惊蛰',
    '森': '森蚺',
    '森蚪': '森蚺',
    '森蛾': '森蚺',
    '森螃': '森蚺',
    '峨': '嵯峨',
    '送峨': '嵯峨',
    '唉峨': '嵯峨',
    '爱哦': '嵯峨',
    '送哦': '嵯峨',
    '峡峨': '嵯峨',
    '(峨': '嵯峨',
    '光恪': '炎熔',
    '光烙': '炎熔',
    '光熔': '炎熔',
    '光焙': '炎熔',
    '我烙': '炎熔',
    '我熔': '炎熔',
    '我焙': '炎熔',
    '我恪': '炎熔',
    '炎烙': '炎熔',
    '炎焙': '炎熔',
    '炎恪': '炎熔',
    'n炎熔': '炎熔',
    'm炎熔': '炎熔',
    '斤炎熔': '炎熔',
    '而炎熔': '炎熔',
    '听炎熔': '炎熔',
    '了元炎熔': '炎熔',
    '美蓉': '芙蓉',
    '5美蓉': '芙蓉',
    'G芙蓉': '芙蓉',
    '可美蓉': '芙蓉',
    '市美蓉': '芙蓉',
    '听美蓉': '芙蓉',
    '早器': '早露',
    '自金': '白金',
    '6卡缇': '卡缇',
    'G卡缇': '卡缇',
    '了G卡缇': '卡缇',
    '国克洛丝': '克罗丝',
    '家克洛丝': '克罗丝',
    '米格各': '米格鲁',
    '沾': '黑',
    '幽灵盗': '幽灵鲨',
    '卡湿利安': '卡涅利安',
    '辣刺': '棘刺',
    '612F': '12F',
    'S12F': '12F',
    '6夜刀': '夜刀',
    '了G杜林': '杜林',
    '6杜林': '杜林',
    '粹兰': '梓兰',
    '野秦': '野鬃',
}

==> arknights_mower-1.4.3-py3-none-any.whl: arknights_mower/data/ocr.py <==
ocr_error = {
    '削男': '削弱',
    'HU男易': '削弱',
    '背身易': '削弱',
    '尚身易': '削弱',
    '尚小深深': '削弱',
    '技巧概要卷1': '技巧概要·卷1',
    '技巧概要卷2': '技巧概要·卷2',
    '医疗千员': '医疗干员',
    '先锋千员': '先锋干员',
    '近卫千员': '近卫干员',
    '术师千员': '术师干员',
    '辅助千员': '辅助干员',
    '高级资深千员': '高级资深干员',
    '狙击千员': '狙击干员',
    '重装千员': '重装干员',
    '特种千员': '特种干员',
    '资深千员': '资深干员',
    '聚酸醋': '聚酸酯',
    '醋原料': '酯原料',
    '龙门市': '龙门币',
    '酮爆集': '酮凝集',
    '雨凝集': '酮凝集',
    '租击干员': '狙击干员',
    '612F': '12F',
    'S12F': '12F',
    'CastIe3': 'Castle-3',
    'Castle3': 'Castle-3',
    'Lancet2': 'Lancet-2',
    'THRMEX': 'THRM-EX',
    '佛影': '傀影',
    '使影': '傀影',
    '倪影': '傀影',
    '影': '傀影',
    '愧影': '傀影',
    '国克洛丝': '克罗丝',
    '家克洛丝': '克罗丝',
    '卡湿利安': '卡涅利安',
    '6卡缇': '卡缇',
    'G卡缇': '卡缇',
    '了G卡缇': '卡缇',
    '叫米': '古米',
    '叶米': '古米',
    '叶': '吽',
    '哗': '吽',
    '耳': '吽',
    '6夜刀': '夜刀',
    '面夜刀': '夜刀',
    '身': '宴',
    '唉峨': '嵯峨',
    '峡峨': '嵯峨',
    '峨': '嵯峨',
    '槎峨': '嵯峨',
    '爱哦': '嵯峨',
    '送哦': '嵯峨',
    '送峨': '嵯峨',
    '可巡林者': '巡林者',
    '巡林': '巡林者',
    '幽灵': '幽灵鲨',
    '幽灵滥': '幽灵鲨',
    '幽灵盗': '幽灵鲨',
    '惊': '惊蛰',
    '早器': '早露',
    '6杜林': '杜林',
    'I6杜林': '杜林',
    '了G杜林': '杜林',
    '桑甚': '桑葚',
    '桑衰': '桑葚',
    '来': '梓兰',
    '粹兰': '梓兰',
    '辣刺': '棘刺',
    '森': '森蚺',
    '森蚪': '森蚺',
    '森蛾': '森蚺',
    '森螃': '森蚺',
    '深': '深靛',
    '灰': '灰烬',
    'm炎熔': '炎熔',
    'n炎熔': '炎熔',
    '了元炎熔': '炎熔',
    '光恪': '炎熔',
    '光烙': '炎熔',
    '光焙': '炎熔',
    '光熔': '炎熔',
    '听炎熔': '炎熔',
    '我恪': '炎熔',
    '我烙': '炎熔',
    '我焙': '炎熔',
    '我熔': '炎熔',
    '斤炎熔': '炎熔',
    '炎恪': '炎熔',
    '炎烙': '炎熔',
    '炎焙': '炎熔',
    '而炎熔': '炎熔',
    '石': '燧石',
    '狮喝': '狮蝎',
    '狮蜴': '狮蝎',
    '攻兰莎': '玫兰莎',
    '放兰莎': '玫兰莎',
    '救兰莎': '玫兰莎',
    '欢兰莎': '玫兰莎',
    '致兰莎': '玫兰莎',
    '琴迎': '琴柳',
    '自金': '白金',
    '白面': '白面鸮',
    '白面男': '白面鸮',
    '白面鸭': '白面鸮',
    '白面鹑': '白面鸮',
    '白面鹗': '白面鸮',
    '乐': '砾',
    '优乐': '砾',
    '既': '砾',
    '研': '砾',
    '舔': '砾',
    '米格各': '米格鲁',
    '罗比塔': '罗比菈塔',
    '罗比拉塔': '罗比菈塔',
    '罗比益塔': '罗比菈塔',
    '罗比藏塔': '罗比菈塔',
    '5美蓉': '芙蓉',
    'G芙蓉': '芙蓉',
    '可美蓉': '芙蓉',
    '听美蓉': '芙蓉',
    '市美蓉': '芙蓉',
    '美蓉': '芙蓉',
    '.芬': '芬',
    '劳': '芬',
    '节草': '苇草',
    '草': '苇草',
    '荣草': '苇草',
    '蒂草': '苇草',
    '蛇居箱': '蛇屠箱',
    '野': '野鬃',
    '野景': '野鬃',
    '野秦': '野鬃',
    '野紧': '野鬃',
    '星': '陨星',
    '碗星': '陨星',
    '限星': '陨星',
    '番草': '香草',
    '看草': '香草',
    '沾': '黑',
}
